@@ -19,8 +19,20 @@ click.rich_click.OPTION_GROUPS = {
     ]
 }
 
+def print_version(ctx, param, value):
+    if not value or ctx.resilient_parsing:
+        return
+    version_file = open("version.txt", "r")
+    version = version_file.read()
+    version_file.close()
+    click.echo(version)
+    ctx.exit()
+
 
 @shell(prompt="ff > ", intro="Starting ff...")
+@click.option(
+    "--version", is_flag=True, callback=print_version, expose_value=False, is_eager=True
+)
 @click.pass_context
 def cli(ctx):
 
